@@ -45,8 +45,8 @@ pub async fn start(config: Config) -> Result {
     let key_pair = if let Ok(key_pair) = KeyPair::load(SECRET_KEY_PATH, PUBLIC_KEY_PATH).await {
         key_pair
     } else {
-        println!(
-            "WARNING: Failed to load secret key from {}, generating a new one.",
+        warn!(
+            "Failed to load secret key from {}, generating a new one.",
             SECRET_KEY_PATH
         );
         let key_id = if let Some(key_id) = config.key_id.clone() {
@@ -59,10 +59,10 @@ pub async fn start(config: Config) -> Result {
             std::io::stdin().read_line(&mut buf)?;
             buf
         };
-        println!("Generating new PGP key pair for the server...");
+        info!("Generating new PGP key pair for the server...");
         let key_pair = KeyPair::new(key_id)?;
         key_pair.save(SECRET_KEY_PATH, PUBLIC_KEY_PATH).await?;
-        println!(
+        info!(
             "Server key pair generated, private key saved to {}, public key saved to {}.",
             SECRET_KEY_PATH, PUBLIC_KEY_PATH
         );
@@ -91,9 +91,8 @@ pub async fn start(config: Config) -> Result {
     }
     .await;
     if upload_key.is_err() {
-        println!("WARNING: Unable to upload public key to key server.");
+        warn!("Unable to upload public key to key server.");
     }
-    println!("Starting WICRS Server.");
     let server_fingerprint = hex::encode_upper(key_pair.secret_key.fingerprint());
     let key_pair_ws = key_pair.clone();
     let schema = Schema::build(QueryRoot, MutationRoot, EmptySubscription).finish();
@@ -139,6 +138,7 @@ pub async fn start(config: Config) -> Result {
         },
     );
 
+    let schema_sdl = schema.sdl();
     let signed_body_graphql = signed_body.clone();
     let graphql_key_pair = key_pair.clone();
     let graphql_post = warp::any()
@@ -266,16 +266,28 @@ pub async fn start(config: Config) -> Result {
     };
     let server_info_str = serde_json::to_string(&server_info_struct).unwrap();
 
+    let server_info_secret = key_pair.secret_key.clone();
+
     let server_info = warp::path!("v3" / "info").map(move || {
-        create_response(server_info_str.clone().as_str(), &key_pair.secret_key)
+        create_response(server_info_str.clone().as_str(), &server_info_secret)
+            .map_or_else(|e| e.into_response(), |r| r.into_response())
+    });
+    let graphql_schema = warp::path!("v3" / "graphql_schema").map(move || {
+        create_response(&schema_sdl, &key_pair.secret_key)
             .map_or_else(|e| e.into_response(), |r| r.into_response())
     });
 
+    let cors = warp::cors().allow_any_origin();
+    let log = warp::log("wicrs_server::http");
+
     let routes = graphql_post
         .or(server_info)
+        .or(graphql_schema)
         .or(web_socket)
         .or(send_message_init)
-        .or(send_message);
+        .or(send_message)
+        .with(cors)
+        .with(log);
     let server = warp::serve(routes).run(
         config
             .address
@@ -283,12 +295,6 @@ pub async fn start(config: Config) -> Result {
             .expect("Invalid bind address"),
     );
 
-    println!(
-        "WICRS Server {} listening at {}.",
-        env!("CARGO_PKG_VERSION"),
-        config.address
-    );
-
     server.await;
 
     Ok(())
